@@ -1,5 +1,5 @@
 .onAttach <- function(...) {
-  packageStartupMessage("\nUse 'statTargetGUI()' to restart the programe.\n",fill=TRUE)
+  packageStartupMessage("\nUse 'statTarget.gui()' to restart the programe.\n",fill=TRUE)
   #statTarget::statTargetGUI()
   if (interactive()) statTarget.gui()
 }
